echo Verificando tags do Git...
git fetch --tags
@echo off
echo Limpando a pasta dist...
rmdir /s /q dist
echo Construindo a nova versão do pacote...
py -m build
echo Fazendo upload para o PyPI...
twine upload dist/* --verbose
