from pathlib import Path

home = Path.home()

certificado_advys_gov = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\diversos\img_certificado_advys_gov.png'
gov_confirm_robo = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\diversos\img_gov_confirm_robo.png'
gov_confirm_robo_prosseguir = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\diversos\img_gov_confirm_robo_prosseguir.png'
titulo_filtros = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\diversos\img_titulo_filtros.png'
calcular = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calcular.png'
calculo_abortado = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calculo_abortado.png'
calculo_avisos = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calculo_avisos.png'
calculo_avisos_0 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calculo_avisos_0.png'
calculo_finalizado = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calculo_finalizado.png'
calculo_finalizado_0 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calculo_finalizado_0.png'
calculo_nao = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calculo_nao.png'
competencia_calculada = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_competencia_calculada.png'
janela_avisos_vencimento = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\dominio\img_janela_avisos_vencimento.png'
chkbx_fechamento = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_chkbx_fechamento.png'
chkbx_pagamentos_trabalhador = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_chkbx_pagamentos_trabalhador.png'
chkbx_remuneracao_trabalhador = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_chkbx_remuneracao_trabalhador.png'
chkbx_transmissao = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_chkbx_transmissao.png'
competencia_fechada_esocial = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_competencia_fechada_esocial.png'
dctf_atencao = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_dctf_atencao.png'
eventos_enviados = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_eventos_enviados.png'
janela_validados_periodo = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_janela_validados_periodo.png'
relatorio_validados = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_relatorio_validados.png'
select_evento_informado = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_select_evento_informado.png'
sem_dados_para_emitir = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_sem_dados_para_emitir.png'
stattus_esocial_diferente = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_stattus_esocial_diferente.png'
validados_opcoes_nenhum = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_validados_opcoes_nenhum.png'
validados_painel_periodo = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_validados_painel_periodo.png'
btn_continue_atualizacao = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_btn_continue_atualizacao.png'
dominio_web = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_dominio_web.png'
dominio_web_carregando = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_dominio_web_carregando.png'
dominio_web_lista_programas = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_dominio_web_lista_programas.png'
dominio_web_lista_programas_1 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_dominio_web_lista_programas_1.png'
erro_impossivel_localizar = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_erro_impossivel_localizar.png'
icone_escrita_fiscal = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_icone_escrita_fiscal.png'
icone_folha = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_icone_folha.png'
login_fiscal = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_login_fiscal.png'
logo_dominio = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_logo_dominio.png'
logo_escrita_fiscal = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_logo_escrita_fiscal.png'
logo_folha = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_logo_folha.png'
permitir_plugin = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_permitir_plugin.png'
permitir_plugin_en = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_permitir_plugin_en.png'
logo_thomson = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\imt_logo_thomson.png'
aviso_rubrica = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\pagamentos remuneracao\img_aviso_rubrica.png'
chkbx_pagamentos = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\pagamentos remuneracao\img_chkbx_pagamentos.png'
chkbx_remuneracao_1200 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\pagamentos remuneracao\img_chkbx_remuneracao_1200.png'
eventos_atencao = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\pagamentos remuneracao\img_eventos_atencao.png'
pag_eventos = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\pagamentos remuneracao\img_pag_eventos.png'
btn_reticencias = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_btn_reticencias.png'
classificacao_tributaria = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_classificacao_tributaria.png'
classificacao_tributaria_selecionada = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_classificacao_tributaria_selecionada.png'
icone_salvar = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_icone_salvar.png'
janela_extrato_mensal = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_janela_extrato_mensal.png'
janela_liquidos = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_janela_liquidos.png'
janela_recibo = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_janela_recibo.png'
janela_resumo = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_janela_resumo.png'
opt_classificacao_tributaria = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_opt_classificacao_tributaria.png'
radio_todos = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_radio_todos.png'
relacao_empresas = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relacao_empresas.png'
relatorios_caminho = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorios_caminho.png'
relatorios_salvar = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorios_salvar.png'
relatorio_adobe = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_adobe.png'
relatorio_class_tributaria = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_class_tributaria.png'
relatorio_erro_gravacao = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_erro_gravacao.png'
relatorio_extrato_mensal = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_extrato_mensal.png'
relatorio_liquidos_1 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_liquidos_1.png'
relatorio_liquidos_2 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_liquidos_2.png'
relatorio_recibo_folha_1 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_recibo_folha_1.png'
relatorio_recibo_folha_2 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_recibo_folha_2.png'
relatorio_resumo_folha_1 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_resumo_folha_1.png'
relatorio_resumo_folha_2 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_resumo_folha_2.png'
select_planilha_cabecalho = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_select_planilha_cabecalho.png'
select_visualizador_w = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_select_visualizador_w.png'
sem_dados = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_sem_dados.png'
erro_criar_parametro = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\selecionar empresa\img_erro_criar_parametro.png'
erro_sem_parametro = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\selecionar empresa\img_erro_sem_parametro.png'
janela_troca_empresa = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\selecionar empresa\img_janela_troca_empresa.png'
radio_busca_cod = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\selecionar empresa\img_radio_busca_cod.png'
btn_alterar_perfil = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\alterar_perfil\img_btn_alterar_perfil.png'
btn_alterar_perfil_1 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\alterar_perfil\img_btn_alterar_perfil_1.png'
input_pessoa_juridica = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\alterar_perfil\img_input_pessoa_juridica.png'
input_pessoa_juridica_1 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\alterar_perfil\img_input_pessoa_juridica_1.png'
entrar_gov = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\login_ecac\img_entrar_gov.png'
login_gov = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\login_ecac\img_login_gov.png'
btn_emitir_darf = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\relatorios\img_btn_emitir_darf.png'
