from pathlib import Path

home = Path.home()

DIR_DADOS = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados'
ARQ_EMPRESAS_NIBO_JSON = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/empresas_nibo.json'
ARQ_EMPRESAS_ATIVAS_DB = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/empresas_ativas.db'
ARQ_EMPRESAS_ACESSORIAS_JSON = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/empresas_acessorias.json'
ARQ_ENTREGAS_ACESSORIAS_JSON = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/entregas_acessorias.json'
ARQ_EMPRESAS_DOMINIO_WEB_XLSX = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/Empresas Domínio Web.xlsx'
ARQ_CLIENTES_INADIMPLENTES_XLSX = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/Clientes Inadimplentes.xlsx'
ARQ_RELATORIO_DE_CLIENTES_XLSX = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/Relatório de Clientes.xlsx'
ARQ_EMPRESAS_ACESSORIAS_XLSX = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/Empresas Acessórias.xlsx'
ARQ_ENTREGAS_ACESSORIAS_XLSX = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/Entregas Acessórias.xlsx'
ARQ_OBRIGACOES_ACESSORIAS_XLSX = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/Obrigações Acessórias.xlsx'
DIR_EMPRESAS = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Empresas'
DIR_NIBO = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Nibo'
DIR_BOLETOS = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Nibo/Boletos'
DIR_ACESSORIAS = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Acessórias'
DIR_ECONTINUO_UPLOAD = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Acessórias/Econtinuo Upload'
DIR_DOMINIO_WEB = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Domínio Web'
DIR_DEPARTAMENTOS = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Departamentos'
DIR_PESSOAL = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Departamentos/Pessoal'
DIR_FISCAL = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Departamentos/Fiscal'
DIR_FINANCEIRO = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Departamentos/Financeiro'
DIR_CONTABIL = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Departamentos/Contábil'
