from pathlib import Path

# Codificação padrão
ENCODING = "utf-8"

# Diretório raiz do departamento de desenvolvimento
DIR_DESENVOLVIMENTO_REDE = (
    Path.home()
    / "ADVYS ASSESSORIA DE NEGOCIOS EIRELI"
    / "Advys - Documentos"
    / "COMUM"
    / "19- DESENVOLVIMENTO"
)

# Caminhos para armazenar variáveis
CAMINHOS_PY = Path(__file__).parent / "caminhos.py"
IMAGENS_PY = Path(__file__).parent / "imagens.py"
